HIRISE_api.preprocessing.Image_Loader — HIRISE_api documentation

# HIRISE_api.preprocessing.Image_Loader

Functions

`generate_dataloaders`(folder_path[, transform]) | Function that generates the dataloaders for a HIRISE dataset, given folder path specified by the user
`generate_dataset`(folder_path[, transform]) | Function that generated the HIRISE Dataset given a folderpath of HIRISE Images
`initialize_encoder_decoder`([latent_dimensions]) | Fuction that initialized the encoder and decoder depeining on the latent
`show_classes`(folder_path[, transform, ...]) | Function that shows all classes defined by the user though the Image Folders using the Image Folder dataset
`show_encoder_decoder_image_sizes`(folder_path) | Function that returns the input and output image sizes of images that have been through the autoencoding process

Classes

`HiriseImageDataset`(path_to_images[, transform]) | Hirise Image Dataset Class that initialize the pytorch ImageLoader Dataset with the folder images to return and image and associated folder name( label)